@@ -2,10 +2,10 @@
 import sys
 
 #from .richdb import rich, pray, Time, mdict, wull, WULL
-from .ztime import Time,orange
+from .ztime import Time, orange, fmt
 from .richdb import rich, pray, q
 from .mdict import mdict
 from .wull import wull, WULL, iswull
 from .vdict import vdict
 from .version import __version__
-__all__ = ('rich', 'Time', 'wull', 'WULL', 'mdict', 'pray', 'iswull', 'q', 'vdict', 'orange', '__version__')
\ No newline at end of file
+__all__ = ('rich', 'Time', 'wull', 'WULL', 'mdict', 'pray', 'iswull', 'q', 'vdict', 'orange', 'fmt', '__version__')
\ No newline at end of file
