@@ -1,9 +1,6 @@
 #-*- encoding=utf8 -*-
 import datetime as dt, time, re, calendar
-from wull import wull, iswull, WULL
-import sys
-from os.path import dirname, abspath
-sys.path.append( dirname( abspath( __file__ ) ) )
+from .wull import wull, iswull, WULL
 
 #Name xxxx-xx-xx xx:xx:xx.xxxxx as standard datetime format, This is very important.
 #use for to make code simple won't be better than this,too many return in for is hard to maintain and debug.
