@@ -1,8 +1,6 @@
 #-*-encoding=utf8-*-
 import os, logging, re, copy, time
 import sys
-from os.path import dirname, abspath
-sys.path.append( dirname( abspath( __file__ ) ) )
 
 from rich.console import Console
 from rich.table import Table
